@@ -22,10 +22,10 @@ import click
 
 from platformio import exception
 from platformio.compat import WINDOWS
-from platformio.managers.core import get_core_package_dir, inject_contrib_pysite
+from platformio.package.manager.core import get_core_package_dir, inject_contrib_pysite
 
 
-@click.command("home", short_help="PIO Home")
+@click.command("home", short_help="UI to manage PlatformIO")
 @click.option("--port", type=int, default=8008, help="HTTP port, default=8008")
 @click.option(
     "--host",
