@@ -12,10 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from platformio import exception
 from platformio.commands.platform import platform_install as cmd_platform_install
 from platformio.commands.test.processor import CTX_META_TEST_RUNNING_NAME
-from platformio.managers.platform import PlatformFactory
+from platformio.platform.exception import UnknownPlatform
+from platformio.platform.factory import PlatformFactory
 from platformio.project.exception import UndefinedEnvPlatformError
 
 # pylint: disable=too-many-instance-attributes
@@ -67,14 +67,14 @@ class EnvironmentProcessor(object):
             build_targets.remove("monitor")
 
         try:
-            p = PlatformFactory.newPlatform(self.options["platform"])
-        except exception.UnknownPlatform:
+            p = PlatformFactory.new(self.options["platform"])
+        except UnknownPlatform:
             self.cmd_ctx.invoke(
                 cmd_platform_install,
                 platforms=[self.options["platform"]],
                 skip_default_package=True,
             )
-            p = PlatformFactory.newPlatform(self.options["platform"])
+            p = PlatformFactory.new(self.options["platform"])
 
         result = p.run(build_vars, build_targets, self.silent, self.verbose, self.jobs)
         return result["returncode"] == 0
