@@ -20,6 +20,7 @@ import tarfile
 import tempfile
 
 from platformio import fs
+from platformio.compat import ensure_python3
 from platformio.package.exception import PackageException
 from platformio.package.manifest.parser import ManifestFileType, ManifestParserFactory
 from platformio.package.manifest.schema import ManifestSchema
@@ -28,20 +29,72 @@ from platformio.package.unpack import FileUnpacker
 
 
 class PackagePacker(object):
+    INCLUDE_DEFAULT = ManifestFileType.items().values()
     EXCLUDE_DEFAULT = [
+        # PlatformIO internal files
+        PackageItem.METAFILE_NAME,
+        ".pio/",
+        "**/.pio/",
+        # Hidden files
         "._*",
         "__*",
         ".DS_Store",
+        ".vscode",
+        ".cache",
+        "**/.cache",
+        # VCS
         ".git/",
         ".hg/",
         ".svn/",
-        ".pio/",
-        "**/.pio/",
-        PackageItem.METAFILE_NAME,
     ]
-    INCLUDE_DEFAULT = ManifestFileType.items().values()
+    EXCLUDE_EXTRA = [
+        # Tests
+        "tests?",
+        # Docs
+        "doc",
+        "docs",
+        "mkdocs",
+        "**/*.[pP][dD][fF]",
+        "**/*.[dD][oO][cC]?",
+        "**/*.[pP][pP][tT]?",
+        "**/*.[dD][oO][xX]",
+        "**/*.[hH][tT][mM]?",
+        "**/*.[tT][eE][xX]",
+        "**/*.[jJ][sS]",
+        "**/*.[cC][sS][sS]",
+        # Binary files
+        "**/*.[jJ][pP][gG]",
+        "**/*.[jJ][pP][eE][gG]",
+        "**/*.[pP][nN][gG]",
+        "**/*.[gG][iI][fF]",
+        "**/*.[zZ][iI][pP]",
+        "**/*.[gG][zZ]",
+        "**/*.3[gG][pP]",
+        "**/*.[mM][oO][vV]",
+        "**/*.[mM][pP][34]",
+        "**/*.[pP][sS][dD]",
+        "**/*.[wW][aA][wW]",
+    ]
+    EXCLUDE_LIBRARY_EXTRA = [
+        "assets",
+        "extra",
+        "resources",
+        "html",
+        "media",
+        "doxygen",
+        "**/build/",
+        "**/*.flat",
+        "**/*.[jJ][aA][rR]",
+        "**/*.[eE][xX][eE]",
+        "**/*.[bB][iI][nN]",
+        "**/*.[hH][eE][xX]",
+        "**/*.[dD][bB]",
+        "**/*.[dD][aA][tT]",
+        "**/*.[dD][lL][lL]",
+    ]
 
     def __init__(self, package, manifest_uri=None):
+        assert ensure_python3()
         self.package = package
         self.manifest_uri = manifest_uri
 
@@ -69,7 +122,6 @@ class PackagePacker(object):
                 src = tmp_dir
 
             src = self.find_source_root(src)
-
             manifest = self.load_manifest(src)
             filename = self.get_archive_name(
                 manifest["name"],
@@ -130,16 +182,32 @@ class PackagePacker(object):
                 json.dump(manifest_updated, fp, indent=2, ensure_ascii=False)
             include = None
 
-        src_filters = self.compute_src_filters(include, exclude)
+        src_filters = self.compute_src_filters(src, include, exclude)
         with tarfile.open(dst, "w:gz") as tar:
             for f in fs.match_src_files(src, src_filters, followlinks=False):
                 tar.add(os.path.join(src, f), f)
         return dst
 
-    def compute_src_filters(self, include, exclude):
+    def compute_src_filters(self, src, include, exclude):
+        exclude_extra = self.EXCLUDE_EXTRA[:]
+        # extend with library extra filters
+        if any(
+            os.path.isfile(os.path.join(src, name))
+            for name in (
+                ManifestFileType.LIBRARY_JSON,
+                ManifestFileType.LIBRARY_PROPERTIES,
+                ManifestFileType.MODULE_JSON,
+            )
+        ):
+            exclude_extra.extend(self.EXCLUDE_LIBRARY_EXTRA)
+
         result = ["+<%s>" % p for p in include or ["*", ".*"]]
-        result += ["-<%s>" % p for p in exclude or []]
         result += ["-<%s>" % p for p in self.EXCLUDE_DEFAULT]
+        # exclude items declared in manifest
+        result += ["-<%s>" % p for p in exclude or []]
+        # apply extra excludes if no custom "export" field in manifest
+        if not include and not exclude:
+            result += ["-<%s>" % p for p in exclude_extra]
         # automatically include manifests
         result += ["+<%s>" % p for p in self.INCLUDE_DEFAULT]
         return result
